# コントリビューター行動規範

## 私たちの誓い

私たちは、メンバー、コントリビューター、およびリーダーとして、年齢、身体の大きさ、目に見えるかどうかにかかわらない障害、民族、性別、性自認およびその表現、経験レベル、教育、社会的地位、国籍、外見、人種、カースト、肌の色、宗教、または性的指向に関係なく、私たちのコミュニティへの参加を、すべての人にとってハラスメントのない体験にすることを誓います。

私たちは、オープンで、歓迎され、多様で、包摂的で、健全なコミュニティに貢献する方法で行動し、交流することを誓います。

## 私たちの基準

私たちのコミュニティにとって肯定的な環境に貢献する行動の例：

* 他の人々に対して共感と優しさを示すこと
* 異なる意見、視点、経験を尊重すること
* 建設的なフィードバックを行い、またそれを快く受け入れること
* 自分の過ちに対する責任を受け入れ、影響を受けた人々に謝罪し、その経験から学ぶこと
* 個人の利益だけでなく、コミュニティ全体の最善に焦点を当てること

容認できない行動の例：

* 性的表現や画像の使用、およびいかなる種類の性的関心や求愛
* トローリング、侮辱的または軽蔑的なコメント、および個人的または政治的な攻撃
* 公的または私的なハラスメント
* 物理的な住所や電子メールアドレスなどの他人の個人情報を、明示的な許可なしに公開すること
* その他、職業的な場において不適切と合理的に見なされる行為

## 執行の責任

コミュニティのリーダーは、許容される行動の基準を明確にし、執行する責任があり、不適切、脅迫的、攻撃的、または有害と見なされる行動に対して、適切かつ公正な是正措置を講じます。

コミュニティのリーダーは、この行動規範に沿わないコメント、コミット、コード、Wikiの編集、課題、およびその他の貢献を削除、編集、または拒否する権利と責任を持ち、適切な場合はモデレーション決定の理由を伝えます。

## 適用範囲

この行動規範は、すべてのコミュニティスペースに適用され、個人が公共の場でコミュニティを公式に代表する場合にも適用されます。
コミュニティを代表する例としては、公式の電子メールアドレスの使用、公式のソーシャルメディアアカウントによる投稿、またはオンラインまたはオフラインのイベントでの指名された代表としての行動などがあります。

## 執行

虐待、ハラスメント、またはその他の容認できない行動の事例は、執行の責任を持つコミュニティリーダー（aimasteracc@gmail.com）に報告することができます。
すべての苦情は、迅速かつ公正に検討され、調査されます。

すべてのコミュニティリーダーは、インシデントの報告者のプライバシーとセキュリティを尊重する義務があります。

## 執行ガイドライン

コミュニティリーダーは、この行動規範に違反すると見なされる行動に対する結果を決定する際に、以下のコミュニティへの影響に関するガイドラインに従います。

### 1. 是正 (Correction)

**コミュニティへの影響**: コミュニティ内でプロフェッショナルでない、または歓迎されないと見なされる不適切な言葉やその他の行動の使用。

**結果**: コミュニティリーダーからの個人的な書面による警告。違反の性質と、その行動が不適切であった理由の説明を提供します。公的な謝罪が求められる場合があります。

### 2. 警告 (Warning)

**コミュニティへの影響**: 単一のインシデントまたは一連の行動による違反。

**結果**: 継続的な行動に対する結果を伴う警告。関係者とのやり取り（行動規範を執行する人々との一方的なやり取りを含む）は、指定された期間禁止されます。これには、コミュニティスペースでのやり取りだけでなく、ソーシャルメディアなどの外部チャネルでのやり取りを避けることも含まれます。これらの条件に違反した場合、一時的または永久的な追放につながる可能性があります。

### 3. 一時的な追放 (Temporary Ban)

**コミュニティへの影響**: 持続的な不適切な行動を含む、コミュニティ基準の重大な違反。

**結果**: 指定された期間、コミュニティとのあらゆる種類のやり取りや公的なコミュニケーションからの一時的な追放。関係者との公的または私的なやり取り（行動規範を執行する人々との一方的なやり取りを含む）は、この期間中は許可されません。これらの条件に違反した場合、永久的な追放につながる可能性があります。

### 4. 永久的な追放 (Permanent Ban)

**コミュニティへの影響**: 持続的な不適切な行動、個人へのハラスメント、または特定の種類の個人に対する攻撃や侮辱を含む、コミュニティ基準の違反パターンの実証。

**結果**: コミュニティ内でのあらゆる種類の公的なやり取りからの永久的な追放。

## 帰属

この行動規範は、[Contributor Covenant][homepage]のバージョン2.1から採用されています。
[https://www.contributor-covenant.org/version/2/1/code_of_conduct.html][v2.1]

コミュニティへの影響に関するガイドラインは、[Mozillaの行動規範執行ラダー][Mozilla CoC]に触発されました。

[homepage]: https://www.contributor-covenant.org
[v2.1]: https://www.contributor-covenant.org/version/2/1/code_of_conduct.html
[Mozilla CoC]: https://github.com/mozilla/diversity
